@@ -431,7 +431,10 @@ sub add_defaults {
             add_defaults($c, $flags, 1);
         }
     }
-    return if $flags_hash->{ADD_USER_ONLY};
+    if($flags_hash->{ADD_USER_ONLY}) {
+        $c->stats->profile(end => "AddDefaults::add_defaults(".$flags_name.")");
+        return;
+    }
 
     $c->stash->{'defaults_added'} = 1;
 
@@ -1521,7 +1524,8 @@ sub _get_flags {
         for my $name (keys %Thruk::Constants::add_defaults) {
             if($Thruk::Constants::add_defaults{$name} == $s) {
                 $flags_hash->{$name} = 1;
-                $name =~ s/ADD_(.+?)S/$1/gmx;
+                $name =~ s/ADD_(.*)/$1/gmx;
+                $name =~ s/S$//gmx;
                 push @{$flags_name}, $name;
                 last;
             }
