@@ -869,12 +869,6 @@ __DATA__
      "type": "",
      "unit": ""
     },
-    {
-     "description": "0/1 flag wether this outage is in a downtime",
-     "name": "in_downtime",
-     "type": "",
-     "unit": ""
-    },
     {
      "description": "last plugin output during outage",
      "name": "plugin_output",
@@ -1103,12 +1097,6 @@ __DATA__
      "type": "",
      "unit": ""
     },
-    {
-     "description": "0/1 flag wether this outage is in a downtime",
-     "name": "in_downtime",
-     "type": "",
-     "unit": ""
-    },
     {
      "description": "last plugin output during outage",
      "name": "plugin_output",
@@ -1289,12 +1277,6 @@ __DATA__
      "type": "",
      "unit": ""
     },
-    {
-     "description": "0/1 flag wether this outage is in a downtime",
-     "name": "in_downtime",
-     "type": "",
-     "unit": ""
-    },
     {
      "description": "last plugin output during outage",
      "name": "plugin_output",
@@ -1931,12 +1913,6 @@ __DATA__
      "type": "",
      "unit": ""
     },
-    {
-     "description": "0/1 flag wether this outage is in a downtime",
-     "name": "in_downtime",
-     "type": "",
-     "unit": ""
-    },
     {
      "description": "last plugin output during outage",
      "name": "plugin_output",
@@ -2195,12 +2171,6 @@ __DATA__
      "type": "",
      "unit": ""
     },
-    {
-     "description": "0/1 flag wether this outage is in a downtime",
-     "name": "in_downtime",
-     "type": "",
-     "unit": ""
-    },
     {
      "description": "last plugin output during outage",
      "name": "plugin_output",
@@ -2417,12 +2387,6 @@ __DATA__
      "type": "",
      "unit": ""
     },
-    {
-     "description": "0/1 flag wether this outage is in a downtime",
-     "name": "in_downtime",
-     "type": "",
-     "unit": ""
-    },
     {
      "description": "last plugin output during outage",
      "name": "plugin_output",
